package com.neko.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.neko.domain.dto.messageDto.SendMessageContentDto;
import com.neko.domain.pojo.Message;
import com.neko.domain.pojo.MessageContentText;
import com.neko.domain.pojo.User;
import com.neko.mapper.MessageContentTextMapper;
import com.neko.mapper.UserMapper;
import com.neko.service.MessageService;
import com.neko.mapper.MessageMapper;
import com.neko.utils.ResultVo;
import com.neko.utils.SnowflakeUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
* @author 金聪
* @description 针对表【message(消息主表)】的数据库操作Service实现
* @createDate 2025-05-18 20:59:28
*/
@Service
public class MessageServiceImpl extends ServiceImpl<MessageMapper, Message>
    implements MessageService{
    @Autowired
    UserMapper userMapper;
    @Autowired
    MessageMapper messageMapper;
    @Autowired
    MessageContentTextMapper messageContentTextMapper;

    @Override
    public boolean sendMessage(SendMessageContentDto dto) {
        Message message = new Message();
        message.setId(String.valueOf(SnowflakeUtil.nextId()));
        String uuid = UUID.randomUUID().toString().replaceAll("-","");
        message.setMessageId("WBNR"+uuid);
        message.setSenderId(dto.getSenderId());
        message.setReceiverId(dto.getReceiverId());
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(User::getId,dto.getReceiverId());
        User user = userMapper.selectOne(queryWrapper);
        if(user!=null){
            message.setReceiverType(1);
        }else{
            message.setMessageType(2);
        }
        message.setMessageType(1);
        //文本内容
        MessageContentText messageContentText = new MessageContentText();
        messageContentText.setId(String.valueOf(SnowflakeUtil.nextId()));
        messageContentText.setContent(dto.getContent());
        messageContentText.setCreateTime(new Date());
        //文本内容

        message.setContentId(messageContentText.getId());
        message.setSendTime(new Date());
        message.setCreateTime(new Date());
        messageMapper.insert(message);
        messageContentTextMapper.insert(messageContentText);

        return true;
    }

    @Override
    public ResultVo findAll(String userId, String receiverId) {
        List<Message> messages = messageMapper.selectList(new LambdaQueryWrapper<Message>()
                .eq(Message::getSenderId, userId)
                .eq(Message::getReceiverId, receiverId));
        List<Message> messages1 = messageMapper.selectList(new LambdaQueryWrapper<Message>()
                .eq(Message::getSenderId, receiverId)
                .eq(Message::getReceiverId, userId));
        for (Message msg : messages1){
            messages.add(msg);
        }
        for (Message message : messages) {
            message.setMessageContentText(messageContentTextMapper.selectById(message.getContentId()));
        }
        System.err.println("messages"+messages);
        return ResultVo.success(messages);
    }

}




